@@ -471,6 +471,8 @@ class PodcastEpisode(PodcastModelObject):
                         self.channel.url, self.url)
                 fn_template = hashlib.md5(self.url.encode('utf-8')).hexdigest()
 
+            # Also sanitize ext (see #591 where ext=.mp3?dest-id=754182)
+            ext = '.' + util.sanitize_filename(ext, self.MAX_FILENAME_LENGTH - len(fn_template) - 1)
             # Find a unique filename for this episode
             wanted_filename = self.find_unique_file_name(fn_template, ext)
 
@@ -1244,6 +1246,12 @@ class Model(object):
 
         return self.children
 
+    def get_podcast(self, url):
+        for p in self.get_podcasts():
+            if p.url == url:
+                return p
+        return None
+
     def load_podcast(self, url, create=True, authentication_tokens=None,
                      max_episodes=0):
         assert all(url != podcast.url for podcast in self.get_podcasts())
